pub struct FilesystemStorageConfig {
pub watch: bool,
pub git_auto_commit: bool,
}Fields
watch: boolgit_auto_commit: boolTrait Implementations
Sourceimpl Clone for FilesystemStorageConfig
impl Clone for FilesystemStorageConfig
Sourcefn clone(&self) -> FilesystemStorageConfig
fn clone(&self) -> FilesystemStorageConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FilesystemStorageConfig
impl Debug for FilesystemStorageConfig
Sourceimpl Default for FilesystemStorageConfig
impl Default for FilesystemStorageConfig
Sourceimpl<'de> Deserialize<'de> for FilesystemStorageConfig
impl<'de> Deserialize<'de> for FilesystemStorageConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for FilesystemStorageConfig
impl Serialize for FilesystemStorageConfig
Sourceimpl TS for FilesystemStorageConfig
impl TS for FilesystemStorageConfig
const EXPORT_TO: Option<&'static str>
Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
interface User { user_id: number, ... }.
This function will panic if the type has no declaration.Sourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten an type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Information about types this type depends on.
This is used for resolving imports when exporting to a file.
Sourcefn transparent() -> bool
fn transparent() -> bool
true if this is a transparent type, e.g tuples or a list.This is used for resolving imports when using the
export! macro.Sourcefn name_with_type_args(args: Vec<String>) -> String
fn name_with_type_args(args: Vec<String>) -> String
Name of this type in TypeScript, with type arguments.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to a file.
The output file can be specified by annotating the type with
#[ts(export_to = ".."].
By default, the filename will be derived from the types name. Read moreSourcefn export_to(path: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_to(path: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type to a file with a file with the specified path. This
function will ignore the
#[ts(export_to = "..)] attribute.Sourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,
Manually generate bindings for this type, returning a
This function does not format the output, even if the
String.This function does not format the output, even if the
format feature is enabled.Auto Trait Implementations
impl Freeze for FilesystemStorageConfig
impl RefUnwindSafe for FilesystemStorageConfig
impl Send for FilesystemStorageConfig
impl Sync for FilesystemStorageConfig
impl Unpin for FilesystemStorageConfig
impl UnsafeUnpin for FilesystemStorageConfig
impl UnwindSafe for FilesystemStorageConfig